@@ -1,6 +1,19 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
 
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
@@ -11,7 +24,7 @@ class SecurityClient(NamespacedClient):
         """
         Enables authentication as a user and retrieve information about the
         authenticated user.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-authenticate.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-authenticate.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_security/_authenticate", params=params, headers=headers
@@ -21,7 +34,7 @@ class SecurityClient(NamespacedClient):
     async def change_password(self, body, username=None, params=None, headers=None):
         """
         Changes the passwords of users in the native realm and built-in users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-change-password.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-change-password.html>`_
 
         :arg body: the new password for the user
         :arg username: The username of the user to change the password
@@ -47,7 +60,7 @@ class SecurityClient(NamespacedClient):
         """
         Evicts users from the user cache. Can completely clear the cache or evict
         specific users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-clear-cache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-clear-cache.html>`_
 
         :arg realms: Comma-separated list of realms to clear
         :arg usernames: Comma-separated list of usernames to clear from
@@ -67,7 +80,7 @@ class SecurityClient(NamespacedClient):
     async def clear_cached_roles(self, name, params=None, headers=None):
         """
         Evicts roles from the native role cache.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-clear-role-cache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-clear-role-cache.html>`_
 
         :arg name: Role name
         """
@@ -85,7 +98,7 @@ class SecurityClient(NamespacedClient):
     async def create_api_key(self, body, params=None, headers=None):
         """
         Creates an API key for access without requiring basic authentication.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-create-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-create-api-key.html>`_
 
         :arg body: The api key request to create an API key
         :arg refresh: If `true` (the default) then refresh the affected
@@ -104,7 +117,7 @@ class SecurityClient(NamespacedClient):
     async def delete_privileges(self, application, name, params=None, headers=None):
         """
         Removes application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-privilege.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-delete-privilege.html>`_
 
         :arg application: Application name
         :arg name: Privilege name
@@ -128,7 +141,7 @@ class SecurityClient(NamespacedClient):
     async def delete_role(self, name, params=None, headers=None):
         """
         Removes roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-delete-role.html>`_
 
         :arg name: Role name
         :arg refresh: If `true` (the default) then refresh the affected
@@ -150,7 +163,7 @@ class SecurityClient(NamespacedClient):
     async def delete_role_mapping(self, name, params=None, headers=None):
         """
         Removes role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-delete-role-mapping.html>`_
 
         :arg name: Role-mapping name
         :arg refresh: If `true` (the default) then refresh the affected
@@ -172,7 +185,7 @@ class SecurityClient(NamespacedClient):
     async def delete_user(self, username, params=None, headers=None):
         """
         Deletes users from the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-delete-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-delete-user.html>`_
 
         :arg username: username
         :arg refresh: If `true` (the default) then refresh the affected
@@ -194,7 +207,7 @@ class SecurityClient(NamespacedClient):
     async def disable_user(self, username, params=None, headers=None):
         """
         Disables users in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-disable-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-disable-user.html>`_
 
         :arg username: The username of the user to disable
         :arg refresh: If `true` (the default) then refresh the affected
@@ -216,7 +229,7 @@ class SecurityClient(NamespacedClient):
     async def enable_user(self, username, params=None, headers=None):
         """
         Enables users in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-enable-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-enable-user.html>`_
 
         :arg username: The username of the user to enable
         :arg refresh: If `true` (the default) then refresh the affected
@@ -238,7 +251,7 @@ class SecurityClient(NamespacedClient):
     async def get_api_key(self, params=None, headers=None):
         """
         Retrieves information for one or more API keys.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-api-key.html>`_
 
         :arg id: API key id of the API key to be retrieved
         :arg name: API key name of the API key to be retrieved
@@ -259,7 +272,7 @@ class SecurityClient(NamespacedClient):
     ):
         """
         Retrieves application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-privileges.html>`_
 
         :arg application: Application name
         :arg name: Privilege name
@@ -275,7 +288,7 @@ class SecurityClient(NamespacedClient):
     async def get_role(self, name=None, params=None, headers=None):
         """
         Retrieves roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-role.html>`_
 
         :arg name: Role name
         """
@@ -287,7 +300,7 @@ class SecurityClient(NamespacedClient):
     async def get_role_mapping(self, name=None, params=None, headers=None):
         """
         Retrieves role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-role-mapping.html>`_
 
         :arg name: Role-Mapping name
         """
@@ -302,7 +315,7 @@ class SecurityClient(NamespacedClient):
     async def get_token(self, body, params=None, headers=None):
         """
         Creates a bearer token for access without requiring basic authentication.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-token.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-token.html>`_
 
         :arg body: The token request to get
         """
@@ -317,7 +330,7 @@ class SecurityClient(NamespacedClient):
     async def get_user(self, username=None, params=None, headers=None):
         """
         Retrieves information about users in the native realm and built-in users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-user.html>`_
 
         :arg username: A comma-separated list of usernames
         """
@@ -332,7 +345,7 @@ class SecurityClient(NamespacedClient):
     async def get_user_privileges(self, params=None, headers=None):
         """
         Retrieves application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-privileges.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_security/user/_privileges", params=params, headers=headers
@@ -342,7 +355,7 @@ class SecurityClient(NamespacedClient):
     async def has_privileges(self, body, user=None, params=None, headers=None):
         """
         Determines whether the specified user has a specified list of privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-has-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-has-privileges.html>`_
 
         :arg body: The privileges to test
         :arg user: Username
@@ -362,7 +375,7 @@ class SecurityClient(NamespacedClient):
     async def invalidate_api_key(self, body, params=None, headers=None):
         """
         Invalidates one or more API keys.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-invalidate-api-key.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-invalidate-api-key.html>`_
 
         :arg body: The api key request to invalidate API key(s)
         """
@@ -377,7 +390,7 @@ class SecurityClient(NamespacedClient):
     async def invalidate_token(self, body, params=None, headers=None):
         """
         Invalidates one or more access tokens or refresh tokens.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-invalidate-token.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-invalidate-token.html>`_
 
         :arg body: The token to invalidate
         """
@@ -396,7 +409,7 @@ class SecurityClient(NamespacedClient):
     async def put_privileges(self, body, params=None, headers=None):
         """
         Adds or updates application privileges.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-put-privileges.html>`_
 
         :arg body: The privilege(s) to add
         :arg refresh: If `true` (the default) then refresh the affected
@@ -415,7 +428,7 @@ class SecurityClient(NamespacedClient):
     async def put_role(self, name, body, params=None, headers=None):
         """
         Adds and updates roles in the native realm.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-role.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-put-role.html>`_
 
         :arg name: Role name
         :arg body: The role to add
@@ -440,7 +453,7 @@ class SecurityClient(NamespacedClient):
     async def put_role_mapping(self, name, body, params=None, headers=None):
         """
         Creates and updates role mappings.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-role-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-put-role-mapping.html>`_
 
         :arg name: Role-mapping name
         :arg body: The role mapping to add
@@ -466,7 +479,7 @@ class SecurityClient(NamespacedClient):
         """
         Adds and updates users in the native realm. These users are commonly referred
         to as native users.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-put-user.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-put-user.html>`_
 
         :arg username: The username of the User
         :arg body: The user to add
@@ -492,8 +505,28 @@ class SecurityClient(NamespacedClient):
         """
         Retrieves the list of cluster privileges and index privileges that are
         available in this version of Elasticsearch.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.8/security-api-get-builtin-privileges.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-get-builtin-privileges.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_security/privilege/_builtin", params=params, headers=headers
         )
+
+    @query_params()
+    async def clear_cached_privileges(self, application, params=None, headers=None):
+        """
+        Evicts application privileges from the native application privileges cache.
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.9/security-api-clear-privilege-cache.html>`_
+
+        :arg application: A comma-separated list of application names
+        """
+        if application in SKIP_IN_PATH:
+            raise ValueError(
+                "Empty value passed for a required argument 'application'."
+            )
+
+        return await self.transport.perform_request(
+            "POST",
+            _make_path("_security", "privilege", application, "_clear_cache"),
+            params=params,
+            headers=headers,
+        )
